@@ -1,6 +1,6 @@
 from django.urls import reverse
 
-from wagtail.tests.utils.form_data import (
+from wagtail.test.utils.form_data import (
     nested_form_data,
     rich_text,
     streamfield,
