@@ -1,4 +1,4 @@
-from wagtail.core.blocks import StructValue
+from wagtail.blocks import StructValue
 
 from wagtail_cblocks.factories import HeadingBlockFactory, ParagraphBlockFactory
 
