@@ -6,7 +6,7 @@ from django.utils.safestring import mark_safe
 from django.utils.text import slugify
 from django.utils.translation import gettext_lazy as _
 
-from wagtail.core import blocks as core_blocks
+from wagtail import blocks as wagtail_blocks
 from wagtail.documents.blocks import DocumentChooserBlock
 from wagtail.images.blocks import ImageChooserBlock
 
@@ -36,7 +36,7 @@ class CSSClassMixin:
         return context
 
 
-class StyleChoiceBlock(core_blocks.ChoiceBlock):
+class StyleChoiceBlock(wagtail_blocks.ChoiceBlock):
     class Meta:
         label = _("Style")
 
@@ -71,7 +71,7 @@ class StyleChoiceBlock(core_blocks.ChoiceBlock):
                 return style
 
 
-class StylizedStructBlock(CSSClassMixin, core_blocks.StructBlock):
+class StylizedStructBlock(CSSClassMixin, wagtail_blocks.StructBlock):
     """
     A group of sub-blocks which defines an element with different styles.
     """
@@ -109,7 +109,7 @@ HEADING_LEVELS = [
 ]
 
 
-class HeadingValue(core_blocks.StructValue):
+class HeadingValue(wagtail_blocks.StructValue):
     @cached_property
     def tag(self):
         """Return the HTML tag to use for the level."""
@@ -121,13 +121,13 @@ class HeadingValue(core_blocks.StructValue):
         return slugify(self.get('text'))
 
 
-class HeadingBlock(core_blocks.StructBlock):
+class HeadingBlock(wagtail_blocks.StructBlock):
     """
     A section heading with a choosable level.
     """
 
-    text = core_blocks.CharBlock(label=_("Title"), classname='title')
-    level = core_blocks.ChoiceBlock(
+    text = wagtail_blocks.CharBlock(label=_("Title"), classname='title')
+    level = wagtail_blocks.ChoiceBlock(
         choices=HEADING_LEVELS,
         default=2,
         label=_("Level"),
@@ -140,7 +140,7 @@ class HeadingBlock(core_blocks.StructBlock):
         value_class = HeadingValue
 
 
-class ParagraphBlock(core_blocks.RichTextBlock):
+class ParagraphBlock(wagtail_blocks.RichTextBlock):
     """
     A paragraph with simple or customized features.
     """
@@ -162,18 +162,18 @@ class ParagraphBlock(core_blocks.RichTextBlock):
 # ------------------------------------------------------------------------------
 
 
-class LinkTargetBlock(core_blocks.StreamBlock):
+class LinkTargetBlock(wagtail_blocks.StreamBlock):
     """
     The target of a link, used by `LinkBlock`.
     """
 
-    page = core_blocks.PageChooserBlock(
+    page = wagtail_blocks.PageChooserBlock(
         label=_("Page"), icon='doc-empty-inverse'
     )
     document = DocumentChooserBlock(label=_("Document"), icon='doc-full')
     image = ImageChooserBlock(label=_("Image"))
-    url = core_blocks.URLBlock(label=_("External link"))
-    anchor = core_blocks.CharBlock(
+    url = wagtail_blocks.URLBlock(label=_("External link"))
+    anchor = wagtail_blocks.CharBlock(
         label=_("Anchor link"),
         help_text=mark_safe(
             _(
@@ -184,7 +184,8 @@ class LinkTargetBlock(core_blocks.StreamBlock):
     )
 
     def set_name(self, name):
-        self.name = name  # we do not want label defined after that
+        # Do not generate a label from the name as Block.set_name does
+        self.name = name
 
     class Meta:
         icon = 'link'
@@ -192,7 +193,7 @@ class LinkTargetBlock(core_blocks.StreamBlock):
         form_classname = 'link-target-block'
 
 
-class LinkValue(core_blocks.StructValue):
+class LinkValue(wagtail_blocks.StructValue):
     @cached_property
     def href(self):
         """Return the URL of the chosen target or `None` if it is undefined."""
@@ -209,7 +210,7 @@ class LinkValue(core_blocks.StructValue):
         return href
 
 
-class LinkBlock(core_blocks.StructBlock):
+class LinkBlock(wagtail_blocks.StructBlock):
     """
     A link with a target chosen from a range of types - i.e. a page, an URL.
     """
@@ -239,7 +240,7 @@ class ButtonBlock(StylizedStructBlock):
     A button which acts like a link.
     """
 
-    text = core_blocks.CharBlock(label=_("Text"))
+    text = wagtail_blocks.CharBlock(label=_("Text"))
     link = LinkBlock()
 
     class Meta:
@@ -252,13 +253,13 @@ class ButtonBlock(StylizedStructBlock):
 # ------------------------------------------------------------------------------
 
 
-class ImageBlock(core_blocks.StructBlock):
+class ImageBlock(wagtail_blocks.StructBlock):
     """
     An image with optional caption and link.
     """
 
     image = ImageChooserBlock(label=_("Image"))
-    caption = core_blocks.CharBlock(required=False, label=_("Caption"))
+    caption = wagtail_blocks.CharBlock(required=False, label=_("Caption"))
     link = LinkBlock(required=False)
 
     class Meta:
@@ -278,12 +279,12 @@ HORIZONTAL_ALIGNMENTS = [
 HORIZONTAL_ALIGNMENT_DEFAULT = None
 
 
-class ColumnsBlock(core_blocks.StructBlock):
+class ColumnsBlock(wagtail_blocks.StructBlock):
     """
     A list of columns which can be horizontally aligned.
     """
 
-    horizontal_align = core_blocks.ChoiceBlock(
+    horizontal_align = wagtail_blocks.ChoiceBlock(
         choices=HORIZONTAL_ALIGNMENTS,
         default=HORIZONTAL_ALIGNMENT_DEFAULT,
         required=False,
@@ -305,7 +306,7 @@ class ColumnsBlock(core_blocks.StructBlock):
                 )
             column_block = self.meta.column_block
 
-        columns = core_blocks.ListBlock(
+        columns = wagtail_blocks.ListBlock(
             column_block,
             collapsed=True,
             form_classname='columns-block-list',
