@@ -1,7 +1,7 @@
 from django.templatetags.static import static
 from django.utils.html import format_html
 
-from wagtail.core import hooks
+from wagtail import hooks
 
 
 @hooks.register('insert_editor_css')
